# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_topic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v3.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2
from ydb._grpc.v3.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v3.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v3.protos import ydb_table_pb2 as protos_dot_ydb__table__pb2
from ydb._grpc.v3.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_topic.proto',
  package='Ydb.Topic',
  syntax='proto3',
  serialized_options=b'\n\016tech.ydb.topicZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Topic\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16protos/ydb_topic.proto\x12\tYdb.Topic\x1a\x1aprotos/ydb_operation.proto\x1a\x17protos/ydb_scheme.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x16protos/ydb_table.proto\x1a#protos/annotations/validation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"7\n\x0fSupportedCodecs\x12$\n\x06\x63odecs\x18\x01 \x03(\x05\x42\x14\xb2\xe6*\n[1; 19999]\x9a\xe6*\x02\x18\x64\"*\n\x0cOffsetsRange\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\"#\n\x12UpdateTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\x15\n\x13UpdateTokenResponse\"\x95\x11\n\x12StreamWriteMessage\x1a\xe5\x01\n\nFromClient\x12\x41\n\x0cinit_request\x18\x01 \x01(\x0b\x32).Ydb.Topic.StreamWriteMessage.InitRequestH\x00\x12\x43\n\rwrite_request\x18\x02 \x01(\x0b\x32*.Ydb.Topic.StreamWriteMessage.WriteRequestH\x00\x12=\n\x14update_token_request\x18\x03 \x01(\x0b\x32\x1d.Ydb.Topic.UpdateTokenRequestH\x00\x42\x10\n\x0e\x63lient_message\x1a\xbf\x02\n\nFromServer\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x43\n\rinit_response\x18\x03 \x01(\x0b\x32*.Ydb.Topic.StreamWriteMessage.InitResponseH\x00\x12\x45\n\x0ewrite_response\x18\x04 \x01(\x0b\x32+.Ydb.Topic.StreamWriteMessage.WriteResponseH\x00\x12?\n\x15update_token_response\x18\x05 \x01(\x0b\x32\x1e.Ydb.Topic.UpdateTokenResponseH\x00\x42\x10\n\x0eserver_message\x1a\xa3\x02\n\x0bInitRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x13\n\x0bproducer_id\x18\x02 \x01(\t\x12[\n\x12write_session_meta\x18\x03 \x03(\x0b\x32?.Ydb.Topic.StreamWriteMessage.InitRequest.WriteSessionMetaEntry\x12\x1a\n\x10message_group_id\x18\x04 \x01(\tH\x00\x12\x16\n\x0cpartition_id\x18\x05 \x01(\x03H\x00\x12\x17\n\x0fget_last_seq_no\x18\x06 \x01(\x08\x1a\x37\n\x15WriteSessionMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0cpartitioning\x1a\x83\x01\n\x0cInitResponse\x12\x13\n\x0blast_seq_no\x18\x01 \x01(\x03\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x12\x34\n\x10supported_codecs\x18\x04 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x1a\xa4\x02\n\x0cWriteRequest\x12H\n\x08messages\x18\x01 \x03(\x0b\x32\x36.Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData\x12\r\n\x05\x63odec\x18\x02 \x01(\x05\x1a\xba\x01\n\x0bMessageData\x12\x0e\n\x06seq_no\x18\x01 \x01(\x03\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x19\n\x11uncompressed_size\x18\x04 \x01(\x03\x12\x1a\n\x10message_group_id\x18\x05 \x01(\tH\x00\x12\x16\n\x0cpartition_id\x18\x06 \x01(\x03H\x00\x42\x0e\n\x0cpartitioning\x1a\x81\x07\n\rWriteResponse\x12\x42\n\x04\x61\x63ks\x18\x01 \x03(\x0b\x32\x34.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck\x12\x14\n\x0cpartition_id\x18\x02 \x01(\x03\x12U\n\x10write_statistics\x18\x03 \x01(\x0b\x32;.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics\x1a\x8e\x03\n\x08WriteAck\x12\x0e\n\x06seq_no\x18\x01 \x01(\x03\x12O\n\x07written\x18\x02 \x01(\x0b\x32<.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.WrittenH\x00\x12O\n\x07skipped\x18\x03 \x01(\x0b\x32<.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.SkippedH\x00\x1a\x19\n\x07Written\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x1a\x9c\x01\n\x07Skipped\x12S\n\x06reason\x18\x01 \x01(\x0e\x32\x43.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason\"<\n\x06Reason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\x1a\n\x16REASON_ALREADY_WRITTEN\x10\x01\x42\x16\n\x14message_write_status\x1a\xad\x02\n\x0fWriteStatistics\x12\x32\n\x0fpersisting_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13min_queue_wait_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13max_queue_wait_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x19partition_quota_wait_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15topic_quota_wait_time\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x99\x1d\n\x11StreamReadMessage\x1aT\n\x10PartitionSession\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x1a\xea\x04\n\nFromClient\x12@\n\x0cinit_request\x18\x01 \x01(\x0b\x32(.Ydb.Topic.StreamReadMessage.InitRequestH\x00\x12@\n\x0cread_request\x18\x02 \x01(\x0b\x32(.Ydb.Topic.StreamReadMessage.ReadRequestH\x00\x12Q\n\x15\x63ommit_offset_request\x18\x03 \x01(\x0b\x32\x30.Ydb.Topic.StreamReadMessage.CommitOffsetRequestH\x00\x12\x66\n partition_session_status_request\x18\x04 \x01(\x0b\x32:.Ydb.Topic.StreamReadMessage.PartitionSessionStatusRequestH\x00\x12=\n\x14update_token_request\x18\x05 \x01(\x0b\x32\x1d.Ydb.Topic.UpdateTokenRequestH\x00\x12\x66\n start_partition_session_response\x18\x06 \x01(\x0b\x32:.Ydb.Topic.StreamReadMessage.StartPartitionSessionResponseH\x00\x12\x64\n\x1fstop_partition_session_response\x18\x07 \x01(\x0b\x32\x39.Ydb.Topic.StreamReadMessage.StopPartitionSessionResponseH\x00\x42\x10\n\x0e\x63lient_message\x1a\xc4\x05\n\nFromServer\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x42\n\rinit_response\x18\x03 \x01(\x0b\x32).Ydb.Topic.StreamReadMessage.InitResponseH\x00\x12\x42\n\rread_response\x18\x04 \x01(\x0b\x32).Ydb.Topic.StreamReadMessage.ReadResponseH\x00\x12S\n\x16\x63ommit_offset_response\x18\x05 \x01(\x0b\x32\x31.Ydb.Topic.StreamReadMessage.CommitOffsetResponseH\x00\x12h\n!partition_session_status_response\x18\x06 \x01(\x0b\x32;.Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponseH\x00\x12?\n\x15update_token_response\x18\x07 \x01(\x0b\x32\x1e.Ydb.Topic.UpdateTokenResponseH\x00\x12\x64\n\x1fstart_partition_session_request\x18\x08 \x01(\x0b\x32\x39.Ydb.Topic.StreamReadMessage.StartPartitionSessionRequestH\x00\x12\x62\n\x1estop_partition_session_request\x18\t \x01(\x0b\x32\x38.Ydb.Topic.StreamReadMessage.StopPartitionSessionRequestH\x00\x42\x10\n\x0eserver_message\x1a\xa4\x02\n\x0bInitRequest\x12X\n\x14topics_read_settings\x18\x01 \x03(\x0b\x32:.Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings\x12\x10\n\x08\x63onsumer\x18\x02 \x01(\t\x12\x13\n\x0breader_name\x18\x03 \x01(\t\x1a\x93\x01\n\x11TopicReadSettings\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rpartition_ids\x18\x02 \x03(\x03\x12*\n\x07max_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\tread_from\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\"\n\x0cInitResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x1a!\n\x0bReadRequest\x12\x12\n\nbytes_size\x18\x01 \x01(\x03\x1a\xce\x05\n\x0cReadResponse\x12O\n\x0epartition_data\x18\x01 \x03(\x0b\x32\x37.Ydb.Topic.StreamReadMessage.ReadResponse.PartitionData\x12\x12\n\nbytes_size\x18\x02 \x01(\x03\x1a\xa0\x01\n\x0bMessageData\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x0e\n\x06seq_no\x18\x02 \x01(\x03\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x19\n\x11uncompressed_size\x18\x06 \x01(\x03\x12\x18\n\x10message_group_id\x18\x07 \x01(\t\x1a\xc4\x02\n\x05\x42\x61tch\x12K\n\x0cmessage_data\x18\x01 \x03(\x0b\x32\x35.Ydb.Topic.StreamReadMessage.ReadResponse.MessageData\x12\x13\n\x0bproducer_id\x18\x02 \x01(\t\x12\x61\n\x12write_session_meta\x18\x03 \x03(\x0b\x32\x45.Ydb.Topic.StreamReadMessage.ReadResponse.Batch.WriteSessionMetaEntry\x12\r\n\x05\x63odec\x18\x04 \x01(\x05\x12.\n\nwritten_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x37\n\x15WriteSessionMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1ao\n\rPartitionData\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12@\n\x07\x62\x61tches\x18\x02 \x03(\x0b\x32/.Ydb.Topic.StreamReadMessage.ReadResponse.Batch\x1a\xd6\x01\n\x13\x43ommitOffsetRequest\x12^\n\x0e\x63ommit_offsets\x18\x01 \x03(\x0b\x32\x46.Ydb.Topic.StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset\x1a_\n\x15PartitionCommitOffset\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12(\n\x07offsets\x18\x02 \x03(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x1a\xdc\x01\n\x14\x43ommitOffsetResponse\x12p\n\x1cpartitions_committed_offsets\x18\x01 \x03(\x0b\x32J.Ydb.Topic.StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset\x1aR\n\x18PartitionCommittedOffset\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x1a=\n\x1dPartitionSessionStatusRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x1a\xcb\x01\n\x1ePartitionSessionStatusResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x02 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x12\x18\n\x10\x63ommitted_offset\x18\x03 \x01(\x03\x12=\n\x19write_time_high_watermark\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xb6\x01\n\x1cStartPartitionSessionRequest\x12H\n\x11partition_session\x18\x01 \x01(\x0b\x32-.Ydb.Topic.StreamReadMessage.PartitionSession\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x03 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x1a\x95\x01\n\x1dStartPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x18\n\x0bread_offset\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x1a\n\rcommit_offset\x18\x03 \x01(\x03H\x01\x88\x01\x01\x42\x0e\n\x0c_read_offsetB\x10\n\x0e_commit_offset\x1ag\n\x1bStopPartitionSessionRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x10\n\x08graceful\x18\x02 \x01(\x08\x12\x18\n\x10\x63ommitted_offset\x18\x03 \x01(\x03\x1a<\n\x1cStopPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\"\xd6\x03\n\x1e\x41\x64\x64OffsetsToTransactionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x31\n\ntx_control\x18\x03 \x01(\x0b\x32\x1d.Ydb.Table.TransactionControl\x12\x46\n\x06topics\x18\x04 \x03(\x0b\x32\x36.Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets\x12\x10\n\x08\x63onsumer\x18\x05 \x01(\t\x1a\xd7\x01\n\x0cTopicOffsets\x12\x0c\n\x04path\x18\x01 \x01(\t\x12[\n\npartitions\x18\x02 \x03(\x0b\x32G.Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets.PartitionOffsets\x1a\\\n\x10PartitionOffsets\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x02 \x03(\x0b\x32\x17.Ydb.Topic.OffsetsRange\"O\n\x1f\x41\x64\x64OffsetsToTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x1f\n\x1d\x41\x64\x64OffsetsToTransactionResult\"L\n\x13MultipleWindowsStat\x12\x12\n\nper_minute\x18\x01 \x01(\x03\x12\x10\n\x08per_hour\x18\x02 \x01(\x03\x12\x0f\n\x07per_day\x18\x03 \x01(\x03\"\xb3\x04\n\x08\x43onsumer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\timportant\x18\x02 \x01(\x08\x12-\n\tread_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10supported_codecs\x18\x05 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x37\n\nattributes\x18\x06 \x03(\x0b\x32#.Ydb.Topic.Consumer.AttributesEntry\x12\x39\n\x0e\x63onsumer_stats\x18\x07 \x01(\x0b\x32!.Ydb.Topic.Consumer.ConsumerStats\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf3\x01\n\rConsumerStats\x12\x41\n\x1dmin_partitions_last_read_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x11max_read_time_lag\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12max_write_time_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\nbytes_read\x18\x04 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStatJ\x04\x08\x04\x10\x05\"\xbf\x02\n\rAlterConsumer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\rset_important\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x31\n\rset_read_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14set_supported_codecs\x18\x05 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12G\n\x10\x61lter_attributes\x18\x06 \x03(\x0b\x32-.Ydb.Topic.AlterConsumer.AlterAttributesEntry\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0e_set_importantJ\x04\x08\x04\x10\x05\"h\n\x14PartitioningSettings\x12\'\n\x15min_active_partitions\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\'\n\x15partition_count_limit\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xbb\x01\n\x19\x41lterPartitioningSettings\x12\x30\n\x19set_min_active_partitions\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x00\x88\x01\x01\x12\x30\n\x19set_partition_count_limit\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x01\x88\x01\x01\x42\x1c\n\x1a_set_min_active_partitionsB\x1c\n\x1a_set_partition_count_limit\"\xf6\x04\n\x12\x43reateTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12>\n\x15partitioning_settings\x18\x03 \x01(\x0b\x32\x1f.Ydb.Topic.PartitioningSettings\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x14retention_storage_mb\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x34\n\x10supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x38\n&partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12-\n\x1bpartition_write_burst_bytes\x18\t \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x41\n\nattributes\x18\n \x03(\x0b\x32-.Ydb.Topic.CreateTopicRequest.AttributesEntry\x12/\n\tconsumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.ConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12.\n\rmetering_mode\x18\x0c \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07\"C\n\x13\x43reateTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x43reateTopicResult\"v\n\x14\x44\x65scribeTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x15\n\rinclude_stats\x18\x03 \x01(\x08\"E\n\x15\x44\x65scribeTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xa2\x08\n\x13\x44\x65scribeTopicResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12>\n\x15partitioning_settings\x18\x02 \x01(\x0b\x32\x1f.Ydb.Topic.PartitioningSettings\x12@\n\npartitions\x18\x03 \x03(\x0b\x32,.Ydb.Topic.DescribeTopicResult.PartitionInfo\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1c\n\x14retention_storage_mb\x18\x05 \x01(\x03\x12\x34\n\x10supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12.\n&partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x12#\n\x1bpartition_write_burst_bytes\x18\t \x01(\x03\x12\x42\n\nattributes\x18\n \x03(\x0b\x32..Ydb.Topic.DescribeTopicResult.AttributesEntry\x12&\n\tconsumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.Consumer\x12.\n\rmetering_mode\x18\x0c \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x12>\n\x0btopic_stats\x18\r \x01(\x0b\x32).Ydb.Topic.DescribeTopicResult.TopicStats\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xa4\x01\n\rPartitionInfo\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x1b\n\x13\x63hild_partition_ids\x18\x03 \x03(\x03\x12\x1c\n\x14parent_partition_ids\x18\x04 \x03(\x03\x12\x32\n\x0fpartition_stats\x18\x05 \x01(\x0b\x32\x19.Ydb.Topic.PartitionStats\x1a\xcd\x01\n\nTopicStats\x12\x18\n\x10store_size_bytes\x18\x01 \x01(\x03\x12\x37\n\x13min_last_write_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12max_write_time_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\rbytes_written\x18\x04 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStatJ\x04\x08\x06\x10\x07\"\x8b\x01\n\x17\x44\x65scribeConsumerRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08\x63onsumer\x18\x03 \x01(\t\x12\x15\n\rinclude_stats\x18\x04 \x01(\x08\"H\n\x18\x44\x65scribeConsumerResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xde\x06\n\x16\x44\x65scribeConsumerResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12%\n\x08\x63onsumer\x18\x02 \x01(\x0b\x32\x13.Ydb.Topic.Consumer\x12\x43\n\npartitions\x18\x03 \x03(\x0b\x32/.Ydb.Topic.DescribeConsumerResult.PartitionInfo\x1a\x80\x02\n\rPartitionInfo\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x1b\n\x13\x63hild_partition_ids\x18\x03 \x03(\x03\x12\x1c\n\x14parent_partition_ids\x18\x04 \x03(\x03\x12\x32\n\x0fpartition_stats\x18\x05 \x01(\x0b\x32\x19.Ydb.Topic.PartitionStats\x12Z\n\x18partition_consumer_stats\x18\x06 \x01(\x0b\x32\x38.Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats\x1a\xb3\x03\n\x16PartitionConsumerStats\x12\x18\n\x10last_read_offset\x18\x01 \x01(\x03\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x12\x17\n\x0fread_session_id\x18\x03 \x01(\t\x12\x46\n\"partition_read_session_create_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_read_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x11max_read_time_lag\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12max_write_time_lag\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\nbytes_read\x18\x08 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStat\x12\x13\n\x0breader_name\x18\x0b \x01(\t\x12\x1a\n\x12\x63onnection_node_id\x18\x0c \x01(\x05\"\x9c\x02\n\x0ePartitionStats\x12\x32\n\x11partition_offsets\x18\x01 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x12\x18\n\x10store_size_bytes\x18\x02 \x01(\x03\x12\x33\n\x0flast_write_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12max_write_time_lag\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\rbytes_written\x18\x05 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStat\x12\x19\n\x11partition_node_id\x18\x08 \x01(\x05\"\x87\x07\n\x11\x41lterTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12I\n\x1b\x61lter_partitioning_settings\x18\x03 \x01(\x0b\x32$.Ydb.Topic.AlterPartitioningSettings\x12\x37\n\x14set_retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x18set_retention_storage_mb\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x00\x88\x01\x01\x12\x38\n\x14set_supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x41\n*set_partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x01\x88\x01\x01\x12\x36\n\x1fset_partition_write_burst_bytes\x18\t \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x02\x88\x01\x01\x12K\n\x10\x61lter_attributes\x18\n \x03(\x0b\x32\x31.Ydb.Topic.AlterTopicRequest.AlterAttributesEntry\x12\x33\n\radd_consumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.ConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12\x1f\n\x0e\x64rop_consumers\x18\x0c \x03(\tB\x07\x9a\xe6*\x03\x18\xb8\x17\x12:\n\x0f\x61lter_consumers\x18\r \x03(\x0b\x32\x18.Ydb.Topic.AlterConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12\x32\n\x11set_metering_mode\x18\x0e \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1b\n\x19_set_retention_storage_mbB-\n+_set_partition_write_speed_bytes_per_secondB\"\n _set_partition_write_burst_bytesJ\x04\x08\x06\x10\x07\"B\n\x12\x41lterTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x41lterTopicResult\"[\n\x10\x44ropTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"A\n\x11\x44ropTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x11\n\x0f\x44ropTopicResult*\x83\x01\n\x05\x43odec\x12\x15\n\x11\x43ODEC_UNSPECIFIED\x10\x00\x12\r\n\tCODEC_RAW\x10\x01\x12\x0e\n\nCODEC_GZIP\x10\x02\x12\x0e\n\nCODEC_LZOP\x10\x03\x12\x0e\n\nCODEC_ZSTD\x10\x04\x12\x11\n\x0c\x43ODEC_CUSTOM\x10\x90N\"\x05\x08\x05\x10\x8fN\"\n\x08\xa0\x9c\x01\x10\xff\xff\xff\xff\x07*s\n\x0cMeteringMode\x12\x1d\n\x19METERING_MODE_UNSPECIFIED\x10\x00\x12#\n\x1fMETERING_MODE_RESERVED_CAPACITY\x10\x01\x12\x1f\n\x1bMETERING_MODE_REQUEST_UNITS\x10\x02\x42M\n\x0etech.ydb.topicZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Topic\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,protos_dot_ydb__scheme__pb2.DESCRIPTOR,protos_dot_ydb__status__codes__pb2.DESCRIPTOR,protos_dot_ydb__issue__message__pb2.DESCRIPTOR,protos_dot_ydb__table__pb2.DESCRIPTOR,protos_dot_annotations_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_CODEC = _descriptor.EnumDescriptor(
  name='Codec',
  full_name='Ydb.Topic.Codec',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CODEC_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODEC_RAW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODEC_GZIP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODEC_LZOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODEC_ZSTD', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODEC_CUSTOM', index=5, number=10000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12746,
  serialized_end=12877,
)
_sym_db.RegisterEnumDescriptor(_CODEC)

Codec = enum_type_wrapper.EnumTypeWrapper(_CODEC)
_METERINGMODE = _descriptor.EnumDescriptor(
  name='MeteringMode',
  full_name='Ydb.Topic.MeteringMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='METERING_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METERING_MODE_RESERVED_CAPACITY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METERING_MODE_REQUEST_UNITS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12879,
  serialized_end=12994,
)
_sym_db.RegisterEnumDescriptor(_METERINGMODE)

MeteringMode = enum_type_wrapper.EnumTypeWrapper(_METERINGMODE)
CODEC_UNSPECIFIED = 0
CODEC_RAW = 1
CODEC_GZIP = 2
CODEC_LZOP = 3
CODEC_ZSTD = 4
CODEC_CUSTOM = 10000
METERING_MODE_UNSPECIFIED = 0
METERING_MODE_RESERVED_CAPACITY = 1
METERING_MODE_REQUEST_UNITS = 2


_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON = _descriptor.EnumDescriptor(
  name='Reason',
  full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REASON_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REASON_ALREADY_WRITTEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2250,
  serialized_end=2310,
)
_sym_db.RegisterEnumDescriptor(_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON)


_SUPPORTEDCODECS = _descriptor.Descriptor(
  name='SupportedCodecs',
  full_name='Ydb.Topic.SupportedCodecs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='codecs', full_name='Ydb.Topic.SupportedCodecs.codecs', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\n[1; 19999]\232\346*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=334,
)


_OFFSETSRANGE = _descriptor.Descriptor(
  name='OffsetsRange',
  full_name='Ydb.Topic.OffsetsRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='Ydb.Topic.OffsetsRange.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='Ydb.Topic.OffsetsRange.end', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=378,
)


_UPDATETOKENREQUEST = _descriptor.Descriptor(
  name='UpdateTokenRequest',
  full_name='Ydb.Topic.UpdateTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='Ydb.Topic.UpdateTokenRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=415,
)


_UPDATETOKENRESPONSE = _descriptor.Descriptor(
  name='UpdateTokenResponse',
  full_name='Ydb.Topic.UpdateTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=438,
)


_STREAMWRITEMESSAGE_FROMCLIENT = _descriptor.Descriptor(
  name='FromClient',
  full_name='Ydb.Topic.StreamWriteMessage.FromClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='init_request', full_name='Ydb.Topic.StreamWriteMessage.FromClient.init_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_request', full_name='Ydb.Topic.StreamWriteMessage.FromClient.write_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_token_request', full_name='Ydb.Topic.StreamWriteMessage.FromClient.update_token_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='client_message', full_name='Ydb.Topic.StreamWriteMessage.FromClient.client_message',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=464,
  serialized_end=693,
)

_STREAMWRITEMESSAGE_FROMSERVER = _descriptor.Descriptor(
  name='FromServer',
  full_name='Ydb.Topic.StreamWriteMessage.FromServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Topic.StreamWriteMessage.FromServer.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Topic.StreamWriteMessage.FromServer.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_response', full_name='Ydb.Topic.StreamWriteMessage.FromServer.init_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_response', full_name='Ydb.Topic.StreamWriteMessage.FromServer.write_response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_token_response', full_name='Ydb.Topic.StreamWriteMessage.FromServer.update_token_response', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='server_message', full_name='Ydb.Topic.StreamWriteMessage.FromServer.server_message',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=696,
  serialized_end=1015,
)

_STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY = _descriptor.Descriptor(
  name='WriteSessionMetaEntry',
  full_name='Ydb.Topic.StreamWriteMessage.InitRequest.WriteSessionMetaEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.WriteSessionMetaEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.WriteSessionMetaEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1293,
)

_STREAMWRITEMESSAGE_INITREQUEST = _descriptor.Descriptor(
  name='InitRequest',
  full_name='Ydb.Topic.StreamWriteMessage.InitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producer_id', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.producer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_session_meta', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.write_session_meta', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_group_id', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.message_group_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.partition_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_last_seq_no', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.get_last_seq_no', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='partitioning', full_name='Ydb.Topic.StreamWriteMessage.InitRequest.partitioning',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1018,
  serialized_end=1309,
)

_STREAMWRITEMESSAGE_INITRESPONSE = _descriptor.Descriptor(
  name='InitResponse',
  full_name='Ydb.Topic.StreamWriteMessage.InitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_seq_no', full_name='Ydb.Topic.StreamWriteMessage.InitResponse.last_seq_no', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Topic.StreamWriteMessage.InitResponse.session_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.Topic.StreamWriteMessage.InitResponse.partition_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_codecs', full_name='Ydb.Topic.StreamWriteMessage.InitResponse.supported_codecs', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1443,
)

_STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA = _descriptor.Descriptor(
  name='MessageData',
  full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData.seq_no', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uncompressed_size', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData.uncompressed_size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_group_id', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData.message_group_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData.partition_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='partitioning', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData.partitioning',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1552,
  serialized_end=1738,
)

_STREAMWRITEMESSAGE_WRITEREQUEST = _descriptor.Descriptor(
  name='WriteRequest',
  full_name='Ydb.Topic.StreamWriteMessage.WriteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec', full_name='Ydb.Topic.StreamWriteMessage.WriteRequest.codec', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1738,
)

_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN = _descriptor.Descriptor(
  name='Written',
  full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Written',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Written.offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2126,
  serialized_end=2151,
)

_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED = _descriptor.Descriptor(
  name='Skipped',
  full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Skipped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Skipped.reason', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2154,
  serialized_end=2310,
)

_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK = _descriptor.Descriptor(
  name='WriteAck',
  full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.seq_no', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='written', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.written', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skipped', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.skipped', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN, _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message_write_status', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.message_write_status',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1936,
  serialized_end=2334,
)

_STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS = _descriptor.Descriptor(
  name='WriteStatistics',
  full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='persisting_time', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics.persisting_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_queue_wait_time', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics.min_queue_wait_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_queue_wait_time', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics.max_queue_wait_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_quota_wait_time', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics.partition_quota_wait_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_quota_wait_time', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics.topic_quota_wait_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2337,
  serialized_end=2638,
)

_STREAMWRITEMESSAGE_WRITERESPONSE = _descriptor.Descriptor(
  name='WriteResponse',
  full_name='Ydb.Topic.StreamWriteMessage.WriteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='acks', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.acks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.partition_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_statistics', full_name='Ydb.Topic.StreamWriteMessage.WriteResponse.write_statistics', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK, _STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1741,
  serialized_end=2638,
)

_STREAMWRITEMESSAGE = _descriptor.Descriptor(
  name='StreamWriteMessage',
  full_name='Ydb.Topic.StreamWriteMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_STREAMWRITEMESSAGE_FROMCLIENT, _STREAMWRITEMESSAGE_FROMSERVER, _STREAMWRITEMESSAGE_INITREQUEST, _STREAMWRITEMESSAGE_INITRESPONSE, _STREAMWRITEMESSAGE_WRITEREQUEST, _STREAMWRITEMESSAGE_WRITERESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=2638,
)


_STREAMREADMESSAGE_PARTITIONSESSION = _descriptor.Descriptor(
  name='PartitionSession',
  full_name='Ydb.Topic.StreamReadMessage.PartitionSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.PartitionSession.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.StreamReadMessage.PartitionSession.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.Topic.StreamReadMessage.PartitionSession.partition_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2746,
)

_STREAMREADMESSAGE_FROMCLIENT = _descriptor.Descriptor(
  name='FromClient',
  full_name='Ydb.Topic.StreamReadMessage.FromClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='init_request', full_name='Ydb.Topic.StreamReadMessage.FromClient.init_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_request', full_name='Ydb.Topic.StreamReadMessage.FromClient.read_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_offset_request', full_name='Ydb.Topic.StreamReadMessage.FromClient.commit_offset_request', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_session_status_request', full_name='Ydb.Topic.StreamReadMessage.FromClient.partition_session_status_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_token_request', full_name='Ydb.Topic.StreamReadMessage.FromClient.update_token_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_partition_session_response', full_name='Ydb.Topic.StreamReadMessage.FromClient.start_partition_session_response', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_partition_session_response', full_name='Ydb.Topic.StreamReadMessage.FromClient.stop_partition_session_response', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='client_message', full_name='Ydb.Topic.StreamReadMessage.FromClient.client_message',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2749,
  serialized_end=3367,
)

_STREAMREADMESSAGE_FROMSERVER = _descriptor.Descriptor(
  name='FromServer',
  full_name='Ydb.Topic.StreamReadMessage.FromServer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Topic.StreamReadMessage.FromServer.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Topic.StreamReadMessage.FromServer.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_response', full_name='Ydb.Topic.StreamReadMessage.FromServer.init_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_response', full_name='Ydb.Topic.StreamReadMessage.FromServer.read_response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_offset_response', full_name='Ydb.Topic.StreamReadMessage.FromServer.commit_offset_response', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_session_status_response', full_name='Ydb.Topic.StreamReadMessage.FromServer.partition_session_status_response', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_token_response', full_name='Ydb.Topic.StreamReadMessage.FromServer.update_token_response', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_partition_session_request', full_name='Ydb.Topic.StreamReadMessage.FromServer.start_partition_session_request', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_partition_session_request', full_name='Ydb.Topic.StreamReadMessage.FromServer.stop_partition_session_request', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='server_message', full_name='Ydb.Topic.StreamReadMessage.FromServer.server_message',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3370,
  serialized_end=4078,
)

_STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS = _descriptor.Descriptor(
  name='TopicReadSettings',
  full_name='Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_ids', full_name='Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings.partition_ids', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lag', full_name='Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings.max_lag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_from', full_name='Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings.read_from', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4226,
  serialized_end=4373,
)

_STREAMREADMESSAGE_INITREQUEST = _descriptor.Descriptor(
  name='InitRequest',
  full_name='Ydb.Topic.StreamReadMessage.InitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topics_read_settings', full_name='Ydb.Topic.StreamReadMessage.InitRequest.topics_read_settings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer', full_name='Ydb.Topic.StreamReadMessage.InitRequest.consumer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reader_name', full_name='Ydb.Topic.StreamReadMessage.InitRequest.reader_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4081,
  serialized_end=4373,
)

_STREAMREADMESSAGE_INITRESPONSE = _descriptor.Descriptor(
  name='InitResponse',
  full_name='Ydb.Topic.StreamReadMessage.InitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Topic.StreamReadMessage.InitResponse.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4375,
  serialized_end=4409,
)

_STREAMREADMESSAGE_READREQUEST = _descriptor.Descriptor(
  name='ReadRequest',
  full_name='Ydb.Topic.StreamReadMessage.ReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes_size', full_name='Ydb.Topic.StreamReadMessage.ReadRequest.bytes_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4411,
  serialized_end=4444,
)

_STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA = _descriptor.Descriptor(
  name='MessageData',
  full_name='Ydb.Topic.StreamReadMessage.ReadResponse.MessageData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.MessageData.offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq_no', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.MessageData.seq_no', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.MessageData.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.MessageData.data', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uncompressed_size', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.MessageData.uncompressed_size', index=4,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_group_id', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.MessageData.message_group_id', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4565,
  serialized_end=4725,
)

_STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY = _descriptor.Descriptor(
  name='WriteSessionMetaEntry',
  full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch.WriteSessionMetaEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch.WriteSessionMetaEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch.WriteSessionMetaEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1293,
)

_STREAMREADMESSAGE_READRESPONSE_BATCH = _descriptor.Descriptor(
  name='Batch',
  full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_data', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch.message_data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producer_id', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch.producer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_session_meta', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch.write_session_meta', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch.codec', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='written_at', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.Batch.written_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4728,
  serialized_end=5052,
)

_STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA = _descriptor.Descriptor(
  name='PartitionData',
  full_name='Ydb.Topic.StreamReadMessage.ReadResponse.PartitionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.PartitionData.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batches', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.PartitionData.batches', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5054,
  serialized_end=5165,
)

_STREAMREADMESSAGE_READRESPONSE = _descriptor.Descriptor(
  name='ReadResponse',
  full_name='Ydb.Topic.StreamReadMessage.ReadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_data', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.partition_data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_size', full_name='Ydb.Topic.StreamReadMessage.ReadResponse.bytes_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA, _STREAMREADMESSAGE_READRESPONSE_BATCH, _STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4447,
  serialized_end=5165,
)

_STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET = _descriptor.Descriptor(
  name='PartitionCommitOffset',
  full_name='Ydb.Topic.StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offsets', full_name='Ydb.Topic.StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset.offsets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5287,
  serialized_end=5382,
)

_STREAMREADMESSAGE_COMMITOFFSETREQUEST = _descriptor.Descriptor(
  name='CommitOffsetRequest',
  full_name='Ydb.Topic.StreamReadMessage.CommitOffsetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_offsets', full_name='Ydb.Topic.StreamReadMessage.CommitOffsetRequest.commit_offsets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5168,
  serialized_end=5382,
)

_STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET = _descriptor.Descriptor(
  name='PartitionCommittedOffset',
  full_name='Ydb.Topic.StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='committed_offset', full_name='Ydb.Topic.StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset.committed_offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5523,
  serialized_end=5605,
)

_STREAMREADMESSAGE_COMMITOFFSETRESPONSE = _descriptor.Descriptor(
  name='CommitOffsetResponse',
  full_name='Ydb.Topic.StreamReadMessage.CommitOffsetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partitions_committed_offsets', full_name='Ydb.Topic.StreamReadMessage.CommitOffsetResponse.partitions_committed_offsets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5385,
  serialized_end=5605,
)

_STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST = _descriptor.Descriptor(
  name='PartitionSessionStatusRequest',
  full_name='Ydb.Topic.StreamReadMessage.PartitionSessionStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.PartitionSessionStatusRequest.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5607,
  serialized_end=5668,
)

_STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE = _descriptor.Descriptor(
  name='PartitionSessionStatusResponse',
  full_name='Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponse.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_offsets', full_name='Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponse.partition_offsets', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='committed_offset', full_name='Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponse.committed_offset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_time_high_watermark', full_name='Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponse.write_time_high_watermark', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5671,
  serialized_end=5874,
)

_STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST = _descriptor.Descriptor(
  name='StartPartitionSessionRequest',
  full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session', full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionRequest.partition_session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='committed_offset', full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionRequest.committed_offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_offsets', full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionRequest.partition_offsets', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5877,
  serialized_end=6059,
)

_STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE = _descriptor.Descriptor(
  name='StartPartitionSessionResponse',
  full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionResponse.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_offset', full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionResponse.read_offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_offset', full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionResponse.commit_offset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_read_offset', full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionResponse._read_offset',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_commit_offset', full_name='Ydb.Topic.StreamReadMessage.StartPartitionSessionResponse._commit_offset',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6062,
  serialized_end=6211,
)

_STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST = _descriptor.Descriptor(
  name='StopPartitionSessionRequest',
  full_name='Ydb.Topic.StreamReadMessage.StopPartitionSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.StopPartitionSessionRequest.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='graceful', full_name='Ydb.Topic.StreamReadMessage.StopPartitionSessionRequest.graceful', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='committed_offset', full_name='Ydb.Topic.StreamReadMessage.StopPartitionSessionRequest.committed_offset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6213,
  serialized_end=6316,
)

_STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE = _descriptor.Descriptor(
  name='StopPartitionSessionResponse',
  full_name='Ydb.Topic.StreamReadMessage.StopPartitionSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_session_id', full_name='Ydb.Topic.StreamReadMessage.StopPartitionSessionResponse.partition_session_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6318,
  serialized_end=6378,
)

_STREAMREADMESSAGE = _descriptor.Descriptor(
  name='StreamReadMessage',
  full_name='Ydb.Topic.StreamReadMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_STREAMREADMESSAGE_PARTITIONSESSION, _STREAMREADMESSAGE_FROMCLIENT, _STREAMREADMESSAGE_FROMSERVER, _STREAMREADMESSAGE_INITREQUEST, _STREAMREADMESSAGE_INITRESPONSE, _STREAMREADMESSAGE_READREQUEST, _STREAMREADMESSAGE_READRESPONSE, _STREAMREADMESSAGE_COMMITOFFSETREQUEST, _STREAMREADMESSAGE_COMMITOFFSETRESPONSE, _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST, _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE, _STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST, _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE, _STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST, _STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2641,
  serialized_end=6378,
)


_ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS = _descriptor.Descriptor(
  name='PartitionOffsets',
  full_name='Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets.PartitionOffsets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets.PartitionOffsets.partition_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_offsets', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets.PartitionOffsets.partition_offsets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6759,
  serialized_end=6851,
)

_ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS = _descriptor.Descriptor(
  name='TopicOffsets',
  full_name='Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets.partitions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6636,
  serialized_end=6851,
)

_ADDOFFSETSTOTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='AddOffsetsToTransactionRequest',
  full_name='Ydb.Topic.AddOffsetsToTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.session_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_control', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.tx_control', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.topics', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer', full_name='Ydb.Topic.AddOffsetsToTransactionRequest.consumer', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6381,
  serialized_end=6851,
)


_ADDOFFSETSTOTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='AddOffsetsToTransactionResponse',
  full_name='Ydb.Topic.AddOffsetsToTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Topic.AddOffsetsToTransactionResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6853,
  serialized_end=6932,
)


_ADDOFFSETSTOTRANSACTIONRESULT = _descriptor.Descriptor(
  name='AddOffsetsToTransactionResult',
  full_name='Ydb.Topic.AddOffsetsToTransactionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6934,
  serialized_end=6965,
)


_MULTIPLEWINDOWSSTAT = _descriptor.Descriptor(
  name='MultipleWindowsStat',
  full_name='Ydb.Topic.MultipleWindowsStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='per_minute', full_name='Ydb.Topic.MultipleWindowsStat.per_minute', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_hour', full_name='Ydb.Topic.MultipleWindowsStat.per_hour', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_day', full_name='Ydb.Topic.MultipleWindowsStat.per_day', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6967,
  serialized_end=7043,
)


_CONSUMER_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Topic.Consumer.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Topic.Consumer.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Topic.Consumer.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7308,
  serialized_end=7357,
)

_CONSUMER_CONSUMERSTATS = _descriptor.Descriptor(
  name='ConsumerStats',
  full_name='Ydb.Topic.Consumer.ConsumerStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_partitions_last_read_time', full_name='Ydb.Topic.Consumer.ConsumerStats.min_partitions_last_read_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_read_time_lag', full_name='Ydb.Topic.Consumer.ConsumerStats.max_read_time_lag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_write_time_lag', full_name='Ydb.Topic.Consumer.ConsumerStats.max_write_time_lag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_read', full_name='Ydb.Topic.Consumer.ConsumerStats.bytes_read', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7360,
  serialized_end=7603,
)

_CONSUMER = _descriptor.Descriptor(
  name='Consumer',
  full_name='Ydb.Topic.Consumer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Topic.Consumer.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='important', full_name='Ydb.Topic.Consumer.important', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_from', full_name='Ydb.Topic.Consumer.read_from', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_codecs', full_name='Ydb.Topic.Consumer.supported_codecs', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Topic.Consumer.attributes', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_stats', full_name='Ydb.Topic.Consumer.consumer_stats', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONSUMER_ATTRIBUTESENTRY, _CONSUMER_CONSUMERSTATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7046,
  serialized_end=7609,
)


_ALTERCONSUMER_ALTERATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AlterAttributesEntry',
  full_name='Ydb.Topic.AlterConsumer.AlterAttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Topic.AlterConsumer.AlterAttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Topic.AlterConsumer.AlterAttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7853,
  serialized_end=7907,
)

_ALTERCONSUMER = _descriptor.Descriptor(
  name='AlterConsumer',
  full_name='Ydb.Topic.AlterConsumer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Topic.AlterConsumer.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_important', full_name='Ydb.Topic.AlterConsumer.set_important', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_read_from', full_name='Ydb.Topic.AlterConsumer.set_read_from', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_supported_codecs', full_name='Ydb.Topic.AlterConsumer.set_supported_codecs', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_attributes', full_name='Ydb.Topic.AlterConsumer.alter_attributes', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ALTERCONSUMER_ALTERATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_set_important', full_name='Ydb.Topic.AlterConsumer._set_important',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7612,
  serialized_end=7931,
)


_PARTITIONINGSETTINGS = _descriptor.Descriptor(
  name='PartitioningSettings',
  full_name='Ydb.Topic.PartitioningSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_active_partitions', full_name='Ydb.Topic.PartitioningSettings.min_active_partitions', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_count_limit', full_name='Ydb.Topic.PartitioningSettings.partition_count_limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7933,
  serialized_end=8037,
)


_ALTERPARTITIONINGSETTINGS = _descriptor.Descriptor(
  name='AlterPartitioningSettings',
  full_name='Ydb.Topic.AlterPartitioningSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='set_min_active_partitions', full_name='Ydb.Topic.AlterPartitioningSettings.set_min_active_partitions', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_partition_count_limit', full_name='Ydb.Topic.AlterPartitioningSettings.set_partition_count_limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_set_min_active_partitions', full_name='Ydb.Topic.AlterPartitioningSettings._set_min_active_partitions',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_set_partition_count_limit', full_name='Ydb.Topic.AlterPartitioningSettings._set_partition_count_limit',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8040,
  serialized_end=8227,
)


_CREATETOPICREQUEST_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Topic.CreateTopicRequest.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Topic.CreateTopicRequest.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Topic.CreateTopicRequest.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7308,
  serialized_end=7357,
)

_CREATETOPICREQUEST = _descriptor.Descriptor(
  name='CreateTopicRequest',
  full_name='Ydb.Topic.CreateTopicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Topic.CreateTopicRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.CreateTopicRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioning_settings', full_name='Ydb.Topic.CreateTopicRequest.partitioning_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='Ydb.Topic.CreateTopicRequest.retention_period', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_storage_mb', full_name='Ydb.Topic.CreateTopicRequest.retention_storage_mb', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_codecs', full_name='Ydb.Topic.CreateTopicRequest.supported_codecs', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_write_speed_bytes_per_second', full_name='Ydb.Topic.CreateTopicRequest.partition_write_speed_bytes_per_second', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_write_burst_bytes', full_name='Ydb.Topic.CreateTopicRequest.partition_write_burst_bytes', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Topic.CreateTopicRequest.attributes', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumers', full_name='Ydb.Topic.CreateTopicRequest.consumers', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\003\030\270\027', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metering_mode', full_name='Ydb.Topic.CreateTopicRequest.metering_mode', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATETOPICREQUEST_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8230,
  serialized_end=8860,
)


_CREATETOPICRESPONSE = _descriptor.Descriptor(
  name='CreateTopicResponse',
  full_name='Ydb.Topic.CreateTopicResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Topic.CreateTopicResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8862,
  serialized_end=8929,
)


_CREATETOPICRESULT = _descriptor.Descriptor(
  name='CreateTopicResult',
  full_name='Ydb.Topic.CreateTopicResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8931,
  serialized_end=8950,
)


_DESCRIBETOPICREQUEST = _descriptor.Descriptor(
  name='DescribeTopicRequest',
  full_name='Ydb.Topic.DescribeTopicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Topic.DescribeTopicRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.DescribeTopicRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_stats', full_name='Ydb.Topic.DescribeTopicRequest.include_stats', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8952,
  serialized_end=9070,
)


_DESCRIBETOPICRESPONSE = _descriptor.Descriptor(
  name='DescribeTopicResponse',
  full_name='Ydb.Topic.DescribeTopicResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Topic.DescribeTopicResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9072,
  serialized_end=9141,
)


_DESCRIBETOPICRESULT_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Topic.DescribeTopicResult.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Topic.DescribeTopicResult.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Topic.DescribeTopicResult.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7308,
  serialized_end=7357,
)

_DESCRIBETOPICRESULT_PARTITIONINFO = _descriptor.Descriptor(
  name='PartitionInfo',
  full_name='Ydb.Topic.DescribeTopicResult.PartitionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.Topic.DescribeTopicResult.PartitionInfo.partition_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='Ydb.Topic.DescribeTopicResult.PartitionInfo.active', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_partition_ids', full_name='Ydb.Topic.DescribeTopicResult.PartitionInfo.child_partition_ids', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_partition_ids', full_name='Ydb.Topic.DescribeTopicResult.PartitionInfo.parent_partition_ids', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_stats', full_name='Ydb.Topic.DescribeTopicResult.PartitionInfo.partition_stats', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9824,
  serialized_end=9988,
)

_DESCRIBETOPICRESULT_TOPICSTATS = _descriptor.Descriptor(
  name='TopicStats',
  full_name='Ydb.Topic.DescribeTopicResult.TopicStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='store_size_bytes', full_name='Ydb.Topic.DescribeTopicResult.TopicStats.store_size_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_last_write_time', full_name='Ydb.Topic.DescribeTopicResult.TopicStats.min_last_write_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_write_time_lag', full_name='Ydb.Topic.DescribeTopicResult.TopicStats.max_write_time_lag', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_written', full_name='Ydb.Topic.DescribeTopicResult.TopicStats.bytes_written', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9991,
  serialized_end=10196,
)

_DESCRIBETOPICRESULT = _descriptor.Descriptor(
  name='DescribeTopicResult',
  full_name='Ydb.Topic.DescribeTopicResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self', full_name='Ydb.Topic.DescribeTopicResult.self', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitioning_settings', full_name='Ydb.Topic.DescribeTopicResult.partitioning_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='Ydb.Topic.DescribeTopicResult.partitions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_period', full_name='Ydb.Topic.DescribeTopicResult.retention_period', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retention_storage_mb', full_name='Ydb.Topic.DescribeTopicResult.retention_storage_mb', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supported_codecs', full_name='Ydb.Topic.DescribeTopicResult.supported_codecs', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_write_speed_bytes_per_second', full_name='Ydb.Topic.DescribeTopicResult.partition_write_speed_bytes_per_second', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_write_burst_bytes', full_name='Ydb.Topic.DescribeTopicResult.partition_write_burst_bytes', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Topic.DescribeTopicResult.attributes', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumers', full_name='Ydb.Topic.DescribeTopicResult.consumers', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metering_mode', full_name='Ydb.Topic.DescribeTopicResult.metering_mode', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic_stats', full_name='Ydb.Topic.DescribeTopicResult.topic_stats', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DESCRIBETOPICRESULT_ATTRIBUTESENTRY, _DESCRIBETOPICRESULT_PARTITIONINFO, _DESCRIBETOPICRESULT_TOPICSTATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9144,
  serialized_end=10202,
)


_DESCRIBECONSUMERREQUEST = _descriptor.Descriptor(
  name='DescribeConsumerRequest',
  full_name='Ydb.Topic.DescribeConsumerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Topic.DescribeConsumerRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.DescribeConsumerRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer', full_name='Ydb.Topic.DescribeConsumerRequest.consumer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_stats', full_name='Ydb.Topic.DescribeConsumerRequest.include_stats', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10205,
  serialized_end=10344,
)


_DESCRIBECONSUMERRESPONSE = _descriptor.Descriptor(
  name='DescribeConsumerResponse',
  full_name='Ydb.Topic.DescribeConsumerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Topic.DescribeConsumerResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10346,
  serialized_end=10418,
)


_DESCRIBECONSUMERRESULT_PARTITIONINFO = _descriptor.Descriptor(
  name='PartitionInfo',
  full_name='Ydb.Topic.DescribeConsumerResult.PartitionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_id', full_name='Ydb.Topic.DescribeConsumerResult.PartitionInfo.partition_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='Ydb.Topic.DescribeConsumerResult.PartitionInfo.active', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_partition_ids', full_name='Ydb.Topic.DescribeConsumerResult.PartitionInfo.child_partition_ids', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_partition_ids', full_name='Ydb.Topic.DescribeConsumerResult.PartitionInfo.parent_partition_ids', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_stats', full_name='Ydb.Topic.DescribeConsumerResult.PartitionInfo.partition_stats', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_consumer_stats', full_name='Ydb.Topic.DescribeConsumerResult.PartitionInfo.partition_consumer_stats', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10589,
  serialized_end=10845,
)

_DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS = _descriptor.Descriptor(
  name='PartitionConsumerStats',
  full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_read_offset', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.last_read_offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='committed_offset', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.committed_offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_session_id', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.read_session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_read_session_create_time', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.partition_read_session_create_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_read_time', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.last_read_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_read_time_lag', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.max_read_time_lag', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_write_time_lag', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.max_write_time_lag', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_read', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.bytes_read', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reader_name', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.reader_name', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_node_id', full_name='Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats.connection_node_id', index=9,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10848,
  serialized_end=11283,
)

_DESCRIBECONSUMERRESULT = _descriptor.Descriptor(
  name='DescribeConsumerResult',
  full_name='Ydb.Topic.DescribeConsumerResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self', full_name='Ydb.Topic.DescribeConsumerResult.self', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer', full_name='Ydb.Topic.DescribeConsumerResult.consumer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='Ydb.Topic.DescribeConsumerResult.partitions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DESCRIBECONSUMERRESULT_PARTITIONINFO, _DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10421,
  serialized_end=11283,
)


_PARTITIONSTATS = _descriptor.Descriptor(
  name='PartitionStats',
  full_name='Ydb.Topic.PartitionStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partition_offsets', full_name='Ydb.Topic.PartitionStats.partition_offsets', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_size_bytes', full_name='Ydb.Topic.PartitionStats.store_size_bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_write_time', full_name='Ydb.Topic.PartitionStats.last_write_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_write_time_lag', full_name='Ydb.Topic.PartitionStats.max_write_time_lag', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_written', full_name='Ydb.Topic.PartitionStats.bytes_written', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_node_id', full_name='Ydb.Topic.PartitionStats.partition_node_id', index=5,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11286,
  serialized_end=11570,
)


_ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AlterAttributesEntry',
  full_name='Ydb.Topic.AlterTopicRequest.AlterAttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Topic.AlterTopicRequest.AlterAttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Topic.AlterTopicRequest.AlterAttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7853,
  serialized_end=7907,
)

_ALTERTOPICREQUEST = _descriptor.Descriptor(
  name='AlterTopicRequest',
  full_name='Ydb.Topic.AlterTopicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Topic.AlterTopicRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.AlterTopicRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_partitioning_settings', full_name='Ydb.Topic.AlterTopicRequest.alter_partitioning_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_retention_period', full_name='Ydb.Topic.AlterTopicRequest.set_retention_period', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_retention_storage_mb', full_name='Ydb.Topic.AlterTopicRequest.set_retention_storage_mb', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_supported_codecs', full_name='Ydb.Topic.AlterTopicRequest.set_supported_codecs', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_partition_write_speed_bytes_per_second', full_name='Ydb.Topic.AlterTopicRequest.set_partition_write_speed_bytes_per_second', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_partition_write_burst_bytes', full_name='Ydb.Topic.AlterTopicRequest.set_partition_write_burst_bytes', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_attributes', full_name='Ydb.Topic.AlterTopicRequest.alter_attributes', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_consumers', full_name='Ydb.Topic.AlterTopicRequest.add_consumers', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\003\030\270\027', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drop_consumers', full_name='Ydb.Topic.AlterTopicRequest.drop_consumers', index=10,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\003\030\270\027', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_consumers', full_name='Ydb.Topic.AlterTopicRequest.alter_consumers', index=11,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\232\346*\003\030\270\027', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_metering_mode', full_name='Ydb.Topic.AlterTopicRequest.set_metering_mode', index=12,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_set_retention_storage_mb', full_name='Ydb.Topic.AlterTopicRequest._set_retention_storage_mb',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_set_partition_write_speed_bytes_per_second', full_name='Ydb.Topic.AlterTopicRequest._set_partition_write_speed_bytes_per_second',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_set_partition_write_burst_bytes', full_name='Ydb.Topic.AlterTopicRequest._set_partition_write_burst_bytes',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11573,
  serialized_end=12476,
)


_ALTERTOPICRESPONSE = _descriptor.Descriptor(
  name='AlterTopicResponse',
  full_name='Ydb.Topic.AlterTopicResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Topic.AlterTopicResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12478,
  serialized_end=12544,
)


_ALTERTOPICRESULT = _descriptor.Descriptor(
  name='AlterTopicResult',
  full_name='Ydb.Topic.AlterTopicResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12546,
  serialized_end=12564,
)


_DROPTOPICREQUEST = _descriptor.Descriptor(
  name='DropTopicRequest',
  full_name='Ydb.Topic.DropTopicRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Topic.DropTopicRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Topic.DropTopicRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12566,
  serialized_end=12657,
)


_DROPTOPICRESPONSE = _descriptor.Descriptor(
  name='DropTopicResponse',
  full_name='Ydb.Topic.DropTopicResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Topic.DropTopicResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12659,
  serialized_end=12724,
)


_DROPTOPICRESULT = _descriptor.Descriptor(
  name='DropTopicResult',
  full_name='Ydb.Topic.DropTopicResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12726,
  serialized_end=12743,
)

_STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['init_request'].message_type = _STREAMWRITEMESSAGE_INITREQUEST
_STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['write_request'].message_type = _STREAMWRITEMESSAGE_WRITEREQUEST
_STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['update_token_request'].message_type = _UPDATETOKENREQUEST
_STREAMWRITEMESSAGE_FROMCLIENT.containing_type = _STREAMWRITEMESSAGE
_STREAMWRITEMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['init_request'])
_STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['init_request'].containing_oneof = _STREAMWRITEMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMWRITEMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['write_request'])
_STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['write_request'].containing_oneof = _STREAMWRITEMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMWRITEMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['update_token_request'])
_STREAMWRITEMESSAGE_FROMCLIENT.fields_by_name['update_token_request'].containing_oneof = _STREAMWRITEMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['init_response'].message_type = _STREAMWRITEMESSAGE_INITRESPONSE
_STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['write_response'].message_type = _STREAMWRITEMESSAGE_WRITERESPONSE
_STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['update_token_response'].message_type = _UPDATETOKENRESPONSE
_STREAMWRITEMESSAGE_FROMSERVER.containing_type = _STREAMWRITEMESSAGE
_STREAMWRITEMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['init_response'])
_STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['init_response'].containing_oneof = _STREAMWRITEMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMWRITEMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['write_response'])
_STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['write_response'].containing_oneof = _STREAMWRITEMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMWRITEMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['update_token_response'])
_STREAMWRITEMESSAGE_FROMSERVER.fields_by_name['update_token_response'].containing_oneof = _STREAMWRITEMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY.containing_type = _STREAMWRITEMESSAGE_INITREQUEST
_STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['write_session_meta'].message_type = _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY
_STREAMWRITEMESSAGE_INITREQUEST.containing_type = _STREAMWRITEMESSAGE
_STREAMWRITEMESSAGE_INITREQUEST.oneofs_by_name['partitioning'].fields.append(
  _STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['message_group_id'])
_STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['message_group_id'].containing_oneof = _STREAMWRITEMESSAGE_INITREQUEST.oneofs_by_name['partitioning']
_STREAMWRITEMESSAGE_INITREQUEST.oneofs_by_name['partitioning'].fields.append(
  _STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['partition_id'])
_STREAMWRITEMESSAGE_INITREQUEST.fields_by_name['partition_id'].containing_oneof = _STREAMWRITEMESSAGE_INITREQUEST.oneofs_by_name['partitioning']
_STREAMWRITEMESSAGE_INITRESPONSE.fields_by_name['supported_codecs'].message_type = _SUPPORTEDCODECS
_STREAMWRITEMESSAGE_INITRESPONSE.containing_type = _STREAMWRITEMESSAGE
_STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.containing_type = _STREAMWRITEMESSAGE_WRITEREQUEST
_STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.oneofs_by_name['partitioning'].fields.append(
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['message_group_id'])
_STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['message_group_id'].containing_oneof = _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.oneofs_by_name['partitioning']
_STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.oneofs_by_name['partitioning'].fields.append(
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['partition_id'])
_STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['partition_id'].containing_oneof = _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.oneofs_by_name['partitioning']
_STREAMWRITEMESSAGE_WRITEREQUEST.fields_by_name['messages'].message_type = _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA
_STREAMWRITEMESSAGE_WRITEREQUEST.containing_type = _STREAMWRITEMESSAGE
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN.containing_type = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED.fields_by_name['reason'].enum_type = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED.containing_type = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON.containing_type = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.fields_by_name['written'].message_type = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.fields_by_name['skipped'].message_type = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.containing_type = _STREAMWRITEMESSAGE_WRITERESPONSE
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.oneofs_by_name['message_write_status'].fields.append(
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.fields_by_name['written'])
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.fields_by_name['written'].containing_oneof = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.oneofs_by_name['message_write_status']
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.oneofs_by_name['message_write_status'].fields.append(
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.fields_by_name['skipped'])
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.fields_by_name['skipped'].containing_oneof = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK.oneofs_by_name['message_write_status']
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS.fields_by_name['persisting_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS.fields_by_name['min_queue_wait_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS.fields_by_name['max_queue_wait_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS.fields_by_name['partition_quota_wait_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS.fields_by_name['topic_quota_wait_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS.containing_type = _STREAMWRITEMESSAGE_WRITERESPONSE
_STREAMWRITEMESSAGE_WRITERESPONSE.fields_by_name['acks'].message_type = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK
_STREAMWRITEMESSAGE_WRITERESPONSE.fields_by_name['write_statistics'].message_type = _STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS
_STREAMWRITEMESSAGE_WRITERESPONSE.containing_type = _STREAMWRITEMESSAGE
_STREAMREADMESSAGE_PARTITIONSESSION.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['init_request'].message_type = _STREAMREADMESSAGE_INITREQUEST
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['read_request'].message_type = _STREAMREADMESSAGE_READREQUEST
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['commit_offset_request'].message_type = _STREAMREADMESSAGE_COMMITOFFSETREQUEST
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['partition_session_status_request'].message_type = _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['update_token_request'].message_type = _UPDATETOKENREQUEST
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['start_partition_session_response'].message_type = _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['stop_partition_session_response'].message_type = _STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE
_STREAMREADMESSAGE_FROMCLIENT.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMREADMESSAGE_FROMCLIENT.fields_by_name['init_request'])
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['init_request'].containing_oneof = _STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMREADMESSAGE_FROMCLIENT.fields_by_name['read_request'])
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['read_request'].containing_oneof = _STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMREADMESSAGE_FROMCLIENT.fields_by_name['commit_offset_request'])
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['commit_offset_request'].containing_oneof = _STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMREADMESSAGE_FROMCLIENT.fields_by_name['partition_session_status_request'])
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['partition_session_status_request'].containing_oneof = _STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMREADMESSAGE_FROMCLIENT.fields_by_name['update_token_request'])
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['update_token_request'].containing_oneof = _STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMREADMESSAGE_FROMCLIENT.fields_by_name['start_partition_session_response'])
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['start_partition_session_response'].containing_oneof = _STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message'].fields.append(
  _STREAMREADMESSAGE_FROMCLIENT.fields_by_name['stop_partition_session_response'])
_STREAMREADMESSAGE_FROMCLIENT.fields_by_name['stop_partition_session_response'].containing_oneof = _STREAMREADMESSAGE_FROMCLIENT.oneofs_by_name['client_message']
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['init_response'].message_type = _STREAMREADMESSAGE_INITRESPONSE
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['read_response'].message_type = _STREAMREADMESSAGE_READRESPONSE
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['commit_offset_response'].message_type = _STREAMREADMESSAGE_COMMITOFFSETRESPONSE
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['partition_session_status_response'].message_type = _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['update_token_response'].message_type = _UPDATETOKENRESPONSE
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['start_partition_session_request'].message_type = _STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['stop_partition_session_request'].message_type = _STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST
_STREAMREADMESSAGE_FROMSERVER.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMREADMESSAGE_FROMSERVER.fields_by_name['init_response'])
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['init_response'].containing_oneof = _STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMREADMESSAGE_FROMSERVER.fields_by_name['read_response'])
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['read_response'].containing_oneof = _STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMREADMESSAGE_FROMSERVER.fields_by_name['commit_offset_response'])
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['commit_offset_response'].containing_oneof = _STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMREADMESSAGE_FROMSERVER.fields_by_name['partition_session_status_response'])
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['partition_session_status_response'].containing_oneof = _STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMREADMESSAGE_FROMSERVER.fields_by_name['update_token_response'])
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['update_token_response'].containing_oneof = _STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMREADMESSAGE_FROMSERVER.fields_by_name['start_partition_session_request'])
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['start_partition_session_request'].containing_oneof = _STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message'].fields.append(
  _STREAMREADMESSAGE_FROMSERVER.fields_by_name['stop_partition_session_request'])
_STREAMREADMESSAGE_FROMSERVER.fields_by_name['stop_partition_session_request'].containing_oneof = _STREAMREADMESSAGE_FROMSERVER.oneofs_by_name['server_message']
_STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS.fields_by_name['max_lag'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS.fields_by_name['read_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS.containing_type = _STREAMREADMESSAGE_INITREQUEST
_STREAMREADMESSAGE_INITREQUEST.fields_by_name['topics_read_settings'].message_type = _STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS
_STREAMREADMESSAGE_INITREQUEST.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_INITRESPONSE.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_READREQUEST.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA.containing_type = _STREAMREADMESSAGE_READRESPONSE
_STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY.containing_type = _STREAMREADMESSAGE_READRESPONSE_BATCH
_STREAMREADMESSAGE_READRESPONSE_BATCH.fields_by_name['message_data'].message_type = _STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA
_STREAMREADMESSAGE_READRESPONSE_BATCH.fields_by_name['write_session_meta'].message_type = _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY
_STREAMREADMESSAGE_READRESPONSE_BATCH.fields_by_name['written_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMREADMESSAGE_READRESPONSE_BATCH.containing_type = _STREAMREADMESSAGE_READRESPONSE
_STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA.fields_by_name['batches'].message_type = _STREAMREADMESSAGE_READRESPONSE_BATCH
_STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA.containing_type = _STREAMREADMESSAGE_READRESPONSE
_STREAMREADMESSAGE_READRESPONSE.fields_by_name['partition_data'].message_type = _STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA
_STREAMREADMESSAGE_READRESPONSE.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET.fields_by_name['offsets'].message_type = _OFFSETSRANGE
_STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET.containing_type = _STREAMREADMESSAGE_COMMITOFFSETREQUEST
_STREAMREADMESSAGE_COMMITOFFSETREQUEST.fields_by_name['commit_offsets'].message_type = _STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET
_STREAMREADMESSAGE_COMMITOFFSETREQUEST.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET.containing_type = _STREAMREADMESSAGE_COMMITOFFSETRESPONSE
_STREAMREADMESSAGE_COMMITOFFSETRESPONSE.fields_by_name['partitions_committed_offsets'].message_type = _STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET
_STREAMREADMESSAGE_COMMITOFFSETRESPONSE.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE.fields_by_name['partition_offsets'].message_type = _OFFSETSRANGE
_STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE.fields_by_name['write_time_high_watermark'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST.fields_by_name['partition_session'].message_type = _STREAMREADMESSAGE_PARTITIONSESSION
_STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST.fields_by_name['partition_offsets'].message_type = _OFFSETSRANGE
_STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.oneofs_by_name['_read_offset'].fields.append(
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.fields_by_name['read_offset'])
_STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.fields_by_name['read_offset'].containing_oneof = _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.oneofs_by_name['_read_offset']
_STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.oneofs_by_name['_commit_offset'].fields.append(
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.fields_by_name['commit_offset'])
_STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.fields_by_name['commit_offset'].containing_oneof = _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE.oneofs_by_name['_commit_offset']
_STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST.containing_type = _STREAMREADMESSAGE
_STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE.containing_type = _STREAMREADMESSAGE
_ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS.fields_by_name['partition_offsets'].message_type = _OFFSETSRANGE
_ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS.containing_type = _ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS
_ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS.fields_by_name['partitions'].message_type = _ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS
_ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS.containing_type = _ADDOFFSETSTOTRANSACTIONREQUEST
_ADDOFFSETSTOTRANSACTIONREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ADDOFFSETSTOTRANSACTIONREQUEST.fields_by_name['tx_control'].message_type = protos_dot_ydb__table__pb2._TRANSACTIONCONTROL
_ADDOFFSETSTOTRANSACTIONREQUEST.fields_by_name['topics'].message_type = _ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS
_ADDOFFSETSTOTRANSACTIONRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_CONSUMER_ATTRIBUTESENTRY.containing_type = _CONSUMER
_CONSUMER_CONSUMERSTATS.fields_by_name['min_partitions_last_read_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONSUMER_CONSUMERSTATS.fields_by_name['max_read_time_lag'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONSUMER_CONSUMERSTATS.fields_by_name['max_write_time_lag'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONSUMER_CONSUMERSTATS.fields_by_name['bytes_read'].message_type = _MULTIPLEWINDOWSSTAT
_CONSUMER_CONSUMERSTATS.containing_type = _CONSUMER
_CONSUMER.fields_by_name['read_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONSUMER.fields_by_name['supported_codecs'].message_type = _SUPPORTEDCODECS
_CONSUMER.fields_by_name['attributes'].message_type = _CONSUMER_ATTRIBUTESENTRY
_CONSUMER.fields_by_name['consumer_stats'].message_type = _CONSUMER_CONSUMERSTATS
_ALTERCONSUMER_ALTERATTRIBUTESENTRY.containing_type = _ALTERCONSUMER
_ALTERCONSUMER.fields_by_name['set_read_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALTERCONSUMER.fields_by_name['set_supported_codecs'].message_type = _SUPPORTEDCODECS
_ALTERCONSUMER.fields_by_name['alter_attributes'].message_type = _ALTERCONSUMER_ALTERATTRIBUTESENTRY
_ALTERCONSUMER.oneofs_by_name['_set_important'].fields.append(
  _ALTERCONSUMER.fields_by_name['set_important'])
_ALTERCONSUMER.fields_by_name['set_important'].containing_oneof = _ALTERCONSUMER.oneofs_by_name['_set_important']
_ALTERPARTITIONINGSETTINGS.oneofs_by_name['_set_min_active_partitions'].fields.append(
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_min_active_partitions'])
_ALTERPARTITIONINGSETTINGS.fields_by_name['set_min_active_partitions'].containing_oneof = _ALTERPARTITIONINGSETTINGS.oneofs_by_name['_set_min_active_partitions']
_ALTERPARTITIONINGSETTINGS.oneofs_by_name['_set_partition_count_limit'].fields.append(
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_partition_count_limit'])
_ALTERPARTITIONINGSETTINGS.fields_by_name['set_partition_count_limit'].containing_oneof = _ALTERPARTITIONINGSETTINGS.oneofs_by_name['_set_partition_count_limit']
_CREATETOPICREQUEST_ATTRIBUTESENTRY.containing_type = _CREATETOPICREQUEST
_CREATETOPICREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATETOPICREQUEST.fields_by_name['partitioning_settings'].message_type = _PARTITIONINGSETTINGS
_CREATETOPICREQUEST.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CREATETOPICREQUEST.fields_by_name['supported_codecs'].message_type = _SUPPORTEDCODECS
_CREATETOPICREQUEST.fields_by_name['attributes'].message_type = _CREATETOPICREQUEST_ATTRIBUTESENTRY
_CREATETOPICREQUEST.fields_by_name['consumers'].message_type = _CONSUMER
_CREATETOPICREQUEST.fields_by_name['metering_mode'].enum_type = _METERINGMODE
_CREATETOPICRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBETOPICREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBETOPICRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBETOPICRESULT_ATTRIBUTESENTRY.containing_type = _DESCRIBETOPICRESULT
_DESCRIBETOPICRESULT_PARTITIONINFO.fields_by_name['partition_stats'].message_type = _PARTITIONSTATS
_DESCRIBETOPICRESULT_PARTITIONINFO.containing_type = _DESCRIBETOPICRESULT
_DESCRIBETOPICRESULT_TOPICSTATS.fields_by_name['min_last_write_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DESCRIBETOPICRESULT_TOPICSTATS.fields_by_name['max_write_time_lag'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DESCRIBETOPICRESULT_TOPICSTATS.fields_by_name['bytes_written'].message_type = _MULTIPLEWINDOWSSTAT
_DESCRIBETOPICRESULT_TOPICSTATS.containing_type = _DESCRIBETOPICRESULT
_DESCRIBETOPICRESULT.fields_by_name['self'].message_type = protos_dot_ydb__scheme__pb2._ENTRY
_DESCRIBETOPICRESULT.fields_by_name['partitioning_settings'].message_type = _PARTITIONINGSETTINGS
_DESCRIBETOPICRESULT.fields_by_name['partitions'].message_type = _DESCRIBETOPICRESULT_PARTITIONINFO
_DESCRIBETOPICRESULT.fields_by_name['retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DESCRIBETOPICRESULT.fields_by_name['supported_codecs'].message_type = _SUPPORTEDCODECS
_DESCRIBETOPICRESULT.fields_by_name['attributes'].message_type = _DESCRIBETOPICRESULT_ATTRIBUTESENTRY
_DESCRIBETOPICRESULT.fields_by_name['consumers'].message_type = _CONSUMER
_DESCRIBETOPICRESULT.fields_by_name['metering_mode'].enum_type = _METERINGMODE
_DESCRIBETOPICRESULT.fields_by_name['topic_stats'].message_type = _DESCRIBETOPICRESULT_TOPICSTATS
_DESCRIBECONSUMERREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBECONSUMERRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBECONSUMERRESULT_PARTITIONINFO.fields_by_name['partition_stats'].message_type = _PARTITIONSTATS
_DESCRIBECONSUMERRESULT_PARTITIONINFO.fields_by_name['partition_consumer_stats'].message_type = _DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS
_DESCRIBECONSUMERRESULT_PARTITIONINFO.containing_type = _DESCRIBECONSUMERRESULT
_DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS.fields_by_name['partition_read_session_create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS.fields_by_name['last_read_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS.fields_by_name['max_read_time_lag'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS.fields_by_name['max_write_time_lag'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS.fields_by_name['bytes_read'].message_type = _MULTIPLEWINDOWSSTAT
_DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS.containing_type = _DESCRIBECONSUMERRESULT
_DESCRIBECONSUMERRESULT.fields_by_name['self'].message_type = protos_dot_ydb__scheme__pb2._ENTRY
_DESCRIBECONSUMERRESULT.fields_by_name['consumer'].message_type = _CONSUMER
_DESCRIBECONSUMERRESULT.fields_by_name['partitions'].message_type = _DESCRIBECONSUMERRESULT_PARTITIONINFO
_PARTITIONSTATS.fields_by_name['partition_offsets'].message_type = _OFFSETSRANGE
_PARTITIONSTATS.fields_by_name['last_write_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTITIONSTATS.fields_by_name['max_write_time_lag'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PARTITIONSTATS.fields_by_name['bytes_written'].message_type = _MULTIPLEWINDOWSSTAT
_ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY.containing_type = _ALTERTOPICREQUEST
_ALTERTOPICREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ALTERTOPICREQUEST.fields_by_name['alter_partitioning_settings'].message_type = _ALTERPARTITIONINGSETTINGS
_ALTERTOPICREQUEST.fields_by_name['set_retention_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ALTERTOPICREQUEST.fields_by_name['set_supported_codecs'].message_type = _SUPPORTEDCODECS
_ALTERTOPICREQUEST.fields_by_name['alter_attributes'].message_type = _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY
_ALTERTOPICREQUEST.fields_by_name['add_consumers'].message_type = _CONSUMER
_ALTERTOPICREQUEST.fields_by_name['alter_consumers'].message_type = _ALTERCONSUMER
_ALTERTOPICREQUEST.fields_by_name['set_metering_mode'].enum_type = _METERINGMODE
_ALTERTOPICREQUEST.oneofs_by_name['_set_retention_storage_mb'].fields.append(
  _ALTERTOPICREQUEST.fields_by_name['set_retention_storage_mb'])
_ALTERTOPICREQUEST.fields_by_name['set_retention_storage_mb'].containing_oneof = _ALTERTOPICREQUEST.oneofs_by_name['_set_retention_storage_mb']
_ALTERTOPICREQUEST.oneofs_by_name['_set_partition_write_speed_bytes_per_second'].fields.append(
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_speed_bytes_per_second'])
_ALTERTOPICREQUEST.fields_by_name['set_partition_write_speed_bytes_per_second'].containing_oneof = _ALTERTOPICREQUEST.oneofs_by_name['_set_partition_write_speed_bytes_per_second']
_ALTERTOPICREQUEST.oneofs_by_name['_set_partition_write_burst_bytes'].fields.append(
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_burst_bytes'])
_ALTERTOPICREQUEST.fields_by_name['set_partition_write_burst_bytes'].containing_oneof = _ALTERTOPICREQUEST.oneofs_by_name['_set_partition_write_burst_bytes']
_ALTERTOPICRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DROPTOPICREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DROPTOPICRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['SupportedCodecs'] = _SUPPORTEDCODECS
DESCRIPTOR.message_types_by_name['OffsetsRange'] = _OFFSETSRANGE
DESCRIPTOR.message_types_by_name['UpdateTokenRequest'] = _UPDATETOKENREQUEST
DESCRIPTOR.message_types_by_name['UpdateTokenResponse'] = _UPDATETOKENRESPONSE
DESCRIPTOR.message_types_by_name['StreamWriteMessage'] = _STREAMWRITEMESSAGE
DESCRIPTOR.message_types_by_name['StreamReadMessage'] = _STREAMREADMESSAGE
DESCRIPTOR.message_types_by_name['AddOffsetsToTransactionRequest'] = _ADDOFFSETSTOTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['AddOffsetsToTransactionResponse'] = _ADDOFFSETSTOTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['AddOffsetsToTransactionResult'] = _ADDOFFSETSTOTRANSACTIONRESULT
DESCRIPTOR.message_types_by_name['MultipleWindowsStat'] = _MULTIPLEWINDOWSSTAT
DESCRIPTOR.message_types_by_name['Consumer'] = _CONSUMER
DESCRIPTOR.message_types_by_name['AlterConsumer'] = _ALTERCONSUMER
DESCRIPTOR.message_types_by_name['PartitioningSettings'] = _PARTITIONINGSETTINGS
DESCRIPTOR.message_types_by_name['AlterPartitioningSettings'] = _ALTERPARTITIONINGSETTINGS
DESCRIPTOR.message_types_by_name['CreateTopicRequest'] = _CREATETOPICREQUEST
DESCRIPTOR.message_types_by_name['CreateTopicResponse'] = _CREATETOPICRESPONSE
DESCRIPTOR.message_types_by_name['CreateTopicResult'] = _CREATETOPICRESULT
DESCRIPTOR.message_types_by_name['DescribeTopicRequest'] = _DESCRIBETOPICREQUEST
DESCRIPTOR.message_types_by_name['DescribeTopicResponse'] = _DESCRIBETOPICRESPONSE
DESCRIPTOR.message_types_by_name['DescribeTopicResult'] = _DESCRIBETOPICRESULT
DESCRIPTOR.message_types_by_name['DescribeConsumerRequest'] = _DESCRIBECONSUMERREQUEST
DESCRIPTOR.message_types_by_name['DescribeConsumerResponse'] = _DESCRIBECONSUMERRESPONSE
DESCRIPTOR.message_types_by_name['DescribeConsumerResult'] = _DESCRIBECONSUMERRESULT
DESCRIPTOR.message_types_by_name['PartitionStats'] = _PARTITIONSTATS
DESCRIPTOR.message_types_by_name['AlterTopicRequest'] = _ALTERTOPICREQUEST
DESCRIPTOR.message_types_by_name['AlterTopicResponse'] = _ALTERTOPICRESPONSE
DESCRIPTOR.message_types_by_name['AlterTopicResult'] = _ALTERTOPICRESULT
DESCRIPTOR.message_types_by_name['DropTopicRequest'] = _DROPTOPICREQUEST
DESCRIPTOR.message_types_by_name['DropTopicResponse'] = _DROPTOPICRESPONSE
DESCRIPTOR.message_types_by_name['DropTopicResult'] = _DROPTOPICRESULT
DESCRIPTOR.enum_types_by_name['Codec'] = _CODEC
DESCRIPTOR.enum_types_by_name['MeteringMode'] = _METERINGMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SupportedCodecs = _reflection.GeneratedProtocolMessageType('SupportedCodecs', (_message.Message,), {
  'DESCRIPTOR' : _SUPPORTEDCODECS,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.SupportedCodecs)
  })
_sym_db.RegisterMessage(SupportedCodecs)

OffsetsRange = _reflection.GeneratedProtocolMessageType('OffsetsRange', (_message.Message,), {
  'DESCRIPTOR' : _OFFSETSRANGE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.OffsetsRange)
  })
_sym_db.RegisterMessage(OffsetsRange)

UpdateTokenRequest = _reflection.GeneratedProtocolMessageType('UpdateTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETOKENREQUEST,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.UpdateTokenRequest)
  })
_sym_db.RegisterMessage(UpdateTokenRequest)

UpdateTokenResponse = _reflection.GeneratedProtocolMessageType('UpdateTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETOKENRESPONSE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.UpdateTokenResponse)
  })
_sym_db.RegisterMessage(UpdateTokenResponse)

StreamWriteMessage = _reflection.GeneratedProtocolMessageType('StreamWriteMessage', (_message.Message,), {

  'FromClient' : _reflection.GeneratedProtocolMessageType('FromClient', (_message.Message,), {
    'DESCRIPTOR' : _STREAMWRITEMESSAGE_FROMCLIENT,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.FromClient)
    })
  ,

  'FromServer' : _reflection.GeneratedProtocolMessageType('FromServer', (_message.Message,), {
    'DESCRIPTOR' : _STREAMWRITEMESSAGE_FROMSERVER,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.FromServer)
    })
  ,

  'InitRequest' : _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {

    'WriteSessionMetaEntry' : _reflection.GeneratedProtocolMessageType('WriteSessionMetaEntry', (_message.Message,), {
      'DESCRIPTOR' : _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.InitRequest.WriteSessionMetaEntry)
      })
    ,
    'DESCRIPTOR' : _STREAMWRITEMESSAGE_INITREQUEST,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.InitRequest)
    })
  ,

  'InitResponse' : _reflection.GeneratedProtocolMessageType('InitResponse', (_message.Message,), {
    'DESCRIPTOR' : _STREAMWRITEMESSAGE_INITRESPONSE,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.InitResponse)
    })
  ,

  'WriteRequest' : _reflection.GeneratedProtocolMessageType('WriteRequest', (_message.Message,), {

    'MessageData' : _reflection.GeneratedProtocolMessageType('MessageData', (_message.Message,), {
      'DESCRIPTOR' : _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData)
      })
    ,
    'DESCRIPTOR' : _STREAMWRITEMESSAGE_WRITEREQUEST,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.WriteRequest)
    })
  ,

  'WriteResponse' : _reflection.GeneratedProtocolMessageType('WriteResponse', (_message.Message,), {

    'WriteAck' : _reflection.GeneratedProtocolMessageType('WriteAck', (_message.Message,), {

      'Written' : _reflection.GeneratedProtocolMessageType('Written', (_message.Message,), {
        'DESCRIPTOR' : _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN,
        '__module__' : 'protos.ydb_topic_pb2'
        # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Written)
        })
      ,

      'Skipped' : _reflection.GeneratedProtocolMessageType('Skipped', (_message.Message,), {
        'DESCRIPTOR' : _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED,
        '__module__' : 'protos.ydb_topic_pb2'
        # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Skipped)
        })
      ,
      'DESCRIPTOR' : _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck)
      })
    ,

    'WriteStatistics' : _reflection.GeneratedProtocolMessageType('WriteStatistics', (_message.Message,), {
      'DESCRIPTOR' : _STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics)
      })
    ,
    'DESCRIPTOR' : _STREAMWRITEMESSAGE_WRITERESPONSE,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage.WriteResponse)
    })
  ,
  'DESCRIPTOR' : _STREAMWRITEMESSAGE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamWriteMessage)
  })
_sym_db.RegisterMessage(StreamWriteMessage)
_sym_db.RegisterMessage(StreamWriteMessage.FromClient)
_sym_db.RegisterMessage(StreamWriteMessage.FromServer)
_sym_db.RegisterMessage(StreamWriteMessage.InitRequest)
_sym_db.RegisterMessage(StreamWriteMessage.InitRequest.WriteSessionMetaEntry)
_sym_db.RegisterMessage(StreamWriteMessage.InitResponse)
_sym_db.RegisterMessage(StreamWriteMessage.WriteRequest)
_sym_db.RegisterMessage(StreamWriteMessage.WriteRequest.MessageData)
_sym_db.RegisterMessage(StreamWriteMessage.WriteResponse)
_sym_db.RegisterMessage(StreamWriteMessage.WriteResponse.WriteAck)
_sym_db.RegisterMessage(StreamWriteMessage.WriteResponse.WriteAck.Written)
_sym_db.RegisterMessage(StreamWriteMessage.WriteResponse.WriteAck.Skipped)
_sym_db.RegisterMessage(StreamWriteMessage.WriteResponse.WriteStatistics)

StreamReadMessage = _reflection.GeneratedProtocolMessageType('StreamReadMessage', (_message.Message,), {

  'PartitionSession' : _reflection.GeneratedProtocolMessageType('PartitionSession', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_PARTITIONSESSION,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.PartitionSession)
    })
  ,

  'FromClient' : _reflection.GeneratedProtocolMessageType('FromClient', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_FROMCLIENT,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.FromClient)
    })
  ,

  'FromServer' : _reflection.GeneratedProtocolMessageType('FromServer', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_FROMSERVER,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.FromServer)
    })
  ,

  'InitRequest' : _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {

    'TopicReadSettings' : _reflection.GeneratedProtocolMessageType('TopicReadSettings', (_message.Message,), {
      'DESCRIPTOR' : _STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings)
      })
    ,
    'DESCRIPTOR' : _STREAMREADMESSAGE_INITREQUEST,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.InitRequest)
    })
  ,

  'InitResponse' : _reflection.GeneratedProtocolMessageType('InitResponse', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_INITRESPONSE,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.InitResponse)
    })
  ,

  'ReadRequest' : _reflection.GeneratedProtocolMessageType('ReadRequest', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_READREQUEST,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.ReadRequest)
    })
  ,

  'ReadResponse' : _reflection.GeneratedProtocolMessageType('ReadResponse', (_message.Message,), {

    'MessageData' : _reflection.GeneratedProtocolMessageType('MessageData', (_message.Message,), {
      'DESCRIPTOR' : _STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.ReadResponse.MessageData)
      })
    ,

    'Batch' : _reflection.GeneratedProtocolMessageType('Batch', (_message.Message,), {

      'WriteSessionMetaEntry' : _reflection.GeneratedProtocolMessageType('WriteSessionMetaEntry', (_message.Message,), {
        'DESCRIPTOR' : _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY,
        '__module__' : 'protos.ydb_topic_pb2'
        # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.ReadResponse.Batch.WriteSessionMetaEntry)
        })
      ,
      'DESCRIPTOR' : _STREAMREADMESSAGE_READRESPONSE_BATCH,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.ReadResponse.Batch)
      })
    ,

    'PartitionData' : _reflection.GeneratedProtocolMessageType('PartitionData', (_message.Message,), {
      'DESCRIPTOR' : _STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.ReadResponse.PartitionData)
      })
    ,
    'DESCRIPTOR' : _STREAMREADMESSAGE_READRESPONSE,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.ReadResponse)
    })
  ,

  'CommitOffsetRequest' : _reflection.GeneratedProtocolMessageType('CommitOffsetRequest', (_message.Message,), {

    'PartitionCommitOffset' : _reflection.GeneratedProtocolMessageType('PartitionCommitOffset', (_message.Message,), {
      'DESCRIPTOR' : _STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset)
      })
    ,
    'DESCRIPTOR' : _STREAMREADMESSAGE_COMMITOFFSETREQUEST,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.CommitOffsetRequest)
    })
  ,

  'CommitOffsetResponse' : _reflection.GeneratedProtocolMessageType('CommitOffsetResponse', (_message.Message,), {

    'PartitionCommittedOffset' : _reflection.GeneratedProtocolMessageType('PartitionCommittedOffset', (_message.Message,), {
      'DESCRIPTOR' : _STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset)
      })
    ,
    'DESCRIPTOR' : _STREAMREADMESSAGE_COMMITOFFSETRESPONSE,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.CommitOffsetResponse)
    })
  ,

  'PartitionSessionStatusRequest' : _reflection.GeneratedProtocolMessageType('PartitionSessionStatusRequest', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.PartitionSessionStatusRequest)
    })
  ,

  'PartitionSessionStatusResponse' : _reflection.GeneratedProtocolMessageType('PartitionSessionStatusResponse', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponse)
    })
  ,

  'StartPartitionSessionRequest' : _reflection.GeneratedProtocolMessageType('StartPartitionSessionRequest', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.StartPartitionSessionRequest)
    })
  ,

  'StartPartitionSessionResponse' : _reflection.GeneratedProtocolMessageType('StartPartitionSessionResponse', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.StartPartitionSessionResponse)
    })
  ,

  'StopPartitionSessionRequest' : _reflection.GeneratedProtocolMessageType('StopPartitionSessionRequest', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.StopPartitionSessionRequest)
    })
  ,

  'StopPartitionSessionResponse' : _reflection.GeneratedProtocolMessageType('StopPartitionSessionResponse', (_message.Message,), {
    'DESCRIPTOR' : _STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage.StopPartitionSessionResponse)
    })
  ,
  'DESCRIPTOR' : _STREAMREADMESSAGE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.StreamReadMessage)
  })
_sym_db.RegisterMessage(StreamReadMessage)
_sym_db.RegisterMessage(StreamReadMessage.PartitionSession)
_sym_db.RegisterMessage(StreamReadMessage.FromClient)
_sym_db.RegisterMessage(StreamReadMessage.FromServer)
_sym_db.RegisterMessage(StreamReadMessage.InitRequest)
_sym_db.RegisterMessage(StreamReadMessage.InitRequest.TopicReadSettings)
_sym_db.RegisterMessage(StreamReadMessage.InitResponse)
_sym_db.RegisterMessage(StreamReadMessage.ReadRequest)
_sym_db.RegisterMessage(StreamReadMessage.ReadResponse)
_sym_db.RegisterMessage(StreamReadMessage.ReadResponse.MessageData)
_sym_db.RegisterMessage(StreamReadMessage.ReadResponse.Batch)
_sym_db.RegisterMessage(StreamReadMessage.ReadResponse.Batch.WriteSessionMetaEntry)
_sym_db.RegisterMessage(StreamReadMessage.ReadResponse.PartitionData)
_sym_db.RegisterMessage(StreamReadMessage.CommitOffsetRequest)
_sym_db.RegisterMessage(StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset)
_sym_db.RegisterMessage(StreamReadMessage.CommitOffsetResponse)
_sym_db.RegisterMessage(StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset)
_sym_db.RegisterMessage(StreamReadMessage.PartitionSessionStatusRequest)
_sym_db.RegisterMessage(StreamReadMessage.PartitionSessionStatusResponse)
_sym_db.RegisterMessage(StreamReadMessage.StartPartitionSessionRequest)
_sym_db.RegisterMessage(StreamReadMessage.StartPartitionSessionResponse)
_sym_db.RegisterMessage(StreamReadMessage.StopPartitionSessionRequest)
_sym_db.RegisterMessage(StreamReadMessage.StopPartitionSessionResponse)

AddOffsetsToTransactionRequest = _reflection.GeneratedProtocolMessageType('AddOffsetsToTransactionRequest', (_message.Message,), {

  'TopicOffsets' : _reflection.GeneratedProtocolMessageType('TopicOffsets', (_message.Message,), {

    'PartitionOffsets' : _reflection.GeneratedProtocolMessageType('PartitionOffsets', (_message.Message,), {
      'DESCRIPTOR' : _ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS,
      '__module__' : 'protos.ydb_topic_pb2'
      # @@protoc_insertion_point(class_scope:Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets.PartitionOffsets)
      })
    ,
    'DESCRIPTOR' : _ADDOFFSETSTOTRANSACTIONREQUEST_TOPICOFFSETS,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets)
    })
  ,
  'DESCRIPTOR' : _ADDOFFSETSTOTRANSACTIONREQUEST,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.AddOffsetsToTransactionRequest)
  })
_sym_db.RegisterMessage(AddOffsetsToTransactionRequest)
_sym_db.RegisterMessage(AddOffsetsToTransactionRequest.TopicOffsets)
_sym_db.RegisterMessage(AddOffsetsToTransactionRequest.TopicOffsets.PartitionOffsets)

AddOffsetsToTransactionResponse = _reflection.GeneratedProtocolMessageType('AddOffsetsToTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDOFFSETSTOTRANSACTIONRESPONSE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.AddOffsetsToTransactionResponse)
  })
_sym_db.RegisterMessage(AddOffsetsToTransactionResponse)

AddOffsetsToTransactionResult = _reflection.GeneratedProtocolMessageType('AddOffsetsToTransactionResult', (_message.Message,), {
  'DESCRIPTOR' : _ADDOFFSETSTOTRANSACTIONRESULT,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.AddOffsetsToTransactionResult)
  })
_sym_db.RegisterMessage(AddOffsetsToTransactionResult)

MultipleWindowsStat = _reflection.GeneratedProtocolMessageType('MultipleWindowsStat', (_message.Message,), {
  'DESCRIPTOR' : _MULTIPLEWINDOWSSTAT,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.MultipleWindowsStat)
  })
_sym_db.RegisterMessage(MultipleWindowsStat)

Consumer = _reflection.GeneratedProtocolMessageType('Consumer', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONSUMER_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.Consumer.AttributesEntry)
    })
  ,

  'ConsumerStats' : _reflection.GeneratedProtocolMessageType('ConsumerStats', (_message.Message,), {
    'DESCRIPTOR' : _CONSUMER_CONSUMERSTATS,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.Consumer.ConsumerStats)
    })
  ,
  'DESCRIPTOR' : _CONSUMER,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.Consumer)
  })
_sym_db.RegisterMessage(Consumer)
_sym_db.RegisterMessage(Consumer.AttributesEntry)
_sym_db.RegisterMessage(Consumer.ConsumerStats)

AlterConsumer = _reflection.GeneratedProtocolMessageType('AlterConsumer', (_message.Message,), {

  'AlterAttributesEntry' : _reflection.GeneratedProtocolMessageType('AlterAttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ALTERCONSUMER_ALTERATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.AlterConsumer.AlterAttributesEntry)
    })
  ,
  'DESCRIPTOR' : _ALTERCONSUMER,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.AlterConsumer)
  })
_sym_db.RegisterMessage(AlterConsumer)
_sym_db.RegisterMessage(AlterConsumer.AlterAttributesEntry)

PartitioningSettings = _reflection.GeneratedProtocolMessageType('PartitioningSettings', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONINGSETTINGS,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.PartitioningSettings)
  })
_sym_db.RegisterMessage(PartitioningSettings)

AlterPartitioningSettings = _reflection.GeneratedProtocolMessageType('AlterPartitioningSettings', (_message.Message,), {
  'DESCRIPTOR' : _ALTERPARTITIONINGSETTINGS,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.AlterPartitioningSettings)
  })
_sym_db.RegisterMessage(AlterPartitioningSettings)

CreateTopicRequest = _reflection.GeneratedProtocolMessageType('CreateTopicRequest', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATETOPICREQUEST_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.CreateTopicRequest.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _CREATETOPICREQUEST,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.CreateTopicRequest)
  })
_sym_db.RegisterMessage(CreateTopicRequest)
_sym_db.RegisterMessage(CreateTopicRequest.AttributesEntry)

CreateTopicResponse = _reflection.GeneratedProtocolMessageType('CreateTopicResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETOPICRESPONSE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.CreateTopicResponse)
  })
_sym_db.RegisterMessage(CreateTopicResponse)

CreateTopicResult = _reflection.GeneratedProtocolMessageType('CreateTopicResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATETOPICRESULT,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.CreateTopicResult)
  })
_sym_db.RegisterMessage(CreateTopicResult)

DescribeTopicRequest = _reflection.GeneratedProtocolMessageType('DescribeTopicRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETOPICREQUEST,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeTopicRequest)
  })
_sym_db.RegisterMessage(DescribeTopicRequest)

DescribeTopicResponse = _reflection.GeneratedProtocolMessageType('DescribeTopicResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETOPICRESPONSE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeTopicResponse)
  })
_sym_db.RegisterMessage(DescribeTopicResponse)

DescribeTopicResult = _reflection.GeneratedProtocolMessageType('DescribeTopicResult', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESCRIBETOPICRESULT_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeTopicResult.AttributesEntry)
    })
  ,

  'PartitionInfo' : _reflection.GeneratedProtocolMessageType('PartitionInfo', (_message.Message,), {
    'DESCRIPTOR' : _DESCRIBETOPICRESULT_PARTITIONINFO,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeTopicResult.PartitionInfo)
    })
  ,

  'TopicStats' : _reflection.GeneratedProtocolMessageType('TopicStats', (_message.Message,), {
    'DESCRIPTOR' : _DESCRIBETOPICRESULT_TOPICSTATS,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeTopicResult.TopicStats)
    })
  ,
  'DESCRIPTOR' : _DESCRIBETOPICRESULT,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeTopicResult)
  })
_sym_db.RegisterMessage(DescribeTopicResult)
_sym_db.RegisterMessage(DescribeTopicResult.AttributesEntry)
_sym_db.RegisterMessage(DescribeTopicResult.PartitionInfo)
_sym_db.RegisterMessage(DescribeTopicResult.TopicStats)

DescribeConsumerRequest = _reflection.GeneratedProtocolMessageType('DescribeConsumerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONSUMERREQUEST,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeConsumerRequest)
  })
_sym_db.RegisterMessage(DescribeConsumerRequest)

DescribeConsumerResponse = _reflection.GeneratedProtocolMessageType('DescribeConsumerResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONSUMERRESPONSE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeConsumerResponse)
  })
_sym_db.RegisterMessage(DescribeConsumerResponse)

DescribeConsumerResult = _reflection.GeneratedProtocolMessageType('DescribeConsumerResult', (_message.Message,), {

  'PartitionInfo' : _reflection.GeneratedProtocolMessageType('PartitionInfo', (_message.Message,), {
    'DESCRIPTOR' : _DESCRIBECONSUMERRESULT_PARTITIONINFO,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeConsumerResult.PartitionInfo)
    })
  ,

  'PartitionConsumerStats' : _reflection.GeneratedProtocolMessageType('PartitionConsumerStats', (_message.Message,), {
    'DESCRIPTOR' : _DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats)
    })
  ,
  'DESCRIPTOR' : _DESCRIBECONSUMERRESULT,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DescribeConsumerResult)
  })
_sym_db.RegisterMessage(DescribeConsumerResult)
_sym_db.RegisterMessage(DescribeConsumerResult.PartitionInfo)
_sym_db.RegisterMessage(DescribeConsumerResult.PartitionConsumerStats)

PartitionStats = _reflection.GeneratedProtocolMessageType('PartitionStats', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONSTATS,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.PartitionStats)
  })
_sym_db.RegisterMessage(PartitionStats)

AlterTopicRequest = _reflection.GeneratedProtocolMessageType('AlterTopicRequest', (_message.Message,), {

  'AlterAttributesEntry' : _reflection.GeneratedProtocolMessageType('AlterAttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_topic_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Topic.AlterTopicRequest.AlterAttributesEntry)
    })
  ,
  'DESCRIPTOR' : _ALTERTOPICREQUEST,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.AlterTopicRequest)
  })
_sym_db.RegisterMessage(AlterTopicRequest)
_sym_db.RegisterMessage(AlterTopicRequest.AlterAttributesEntry)

AlterTopicResponse = _reflection.GeneratedProtocolMessageType('AlterTopicResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALTERTOPICRESPONSE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.AlterTopicResponse)
  })
_sym_db.RegisterMessage(AlterTopicResponse)

AlterTopicResult = _reflection.GeneratedProtocolMessageType('AlterTopicResult', (_message.Message,), {
  'DESCRIPTOR' : _ALTERTOPICRESULT,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.AlterTopicResult)
  })
_sym_db.RegisterMessage(AlterTopicResult)

DropTopicRequest = _reflection.GeneratedProtocolMessageType('DropTopicRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPTOPICREQUEST,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DropTopicRequest)
  })
_sym_db.RegisterMessage(DropTopicRequest)

DropTopicResponse = _reflection.GeneratedProtocolMessageType('DropTopicResponse', (_message.Message,), {
  'DESCRIPTOR' : _DROPTOPICRESPONSE,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DropTopicResponse)
  })
_sym_db.RegisterMessage(DropTopicResponse)

DropTopicResult = _reflection.GeneratedProtocolMessageType('DropTopicResult', (_message.Message,), {
  'DESCRIPTOR' : _DROPTOPICRESULT,
  '__module__' : 'protos.ydb_topic_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Topic.DropTopicResult)
  })
_sym_db.RegisterMessage(DropTopicResult)


DESCRIPTOR._options = None
_SUPPORTEDCODECS.fields_by_name['codecs']._options = None
_STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._options = None
_STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._options = None
_CONSUMER_ATTRIBUTESENTRY._options = None
_ALTERCONSUMER_ALTERATTRIBUTESENTRY._options = None
_PARTITIONINGSETTINGS.fields_by_name['min_active_partitions']._options = None
_PARTITIONINGSETTINGS.fields_by_name['partition_count_limit']._options = None
_ALTERPARTITIONINGSETTINGS.fields_by_name['set_min_active_partitions']._options = None
_ALTERPARTITIONINGSETTINGS.fields_by_name['set_partition_count_limit']._options = None
_CREATETOPICREQUEST_ATTRIBUTESENTRY._options = None
_CREATETOPICREQUEST.fields_by_name['retention_storage_mb']._options = None
_CREATETOPICREQUEST.fields_by_name['partition_write_speed_bytes_per_second']._options = None
_CREATETOPICREQUEST.fields_by_name['partition_write_burst_bytes']._options = None
_CREATETOPICREQUEST.fields_by_name['consumers']._options = None
_DESCRIBETOPICRESULT_ATTRIBUTESENTRY._options = None
_ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._options = None
_ALTERTOPICREQUEST.fields_by_name['set_retention_storage_mb']._options = None
_ALTERTOPICREQUEST.fields_by_name['set_partition_write_speed_bytes_per_second']._options = None
_ALTERTOPICREQUEST.fields_by_name['set_partition_write_burst_bytes']._options = None
_ALTERTOPICREQUEST.fields_by_name['add_consumers']._options = None
_ALTERTOPICREQUEST.fields_by_name['drop_consumers']._options = None
_ALTERTOPICREQUEST.fields_by_name['alter_consumers']._options = None
# @@protoc_insertion_point(module_scope)
